@@ -1,9 +1,12 @@
+import six
+
 from . import helpers
 from . import util
 from .attractiveness_finder import AttractivenessFinder
 from .messaging import ThreadFetcher
 from .photo import PhotoUploader
 from .profile import Profile
+from .profile_copy import Copy
 from .question import Questions
 from .search import SearchFetchable, search
 from .session import Session
@@ -107,7 +110,7 @@ class User(object):
 
         """
         # Try to reply to an existing thread.
-        if not isinstance(username, str):
+        if not isinstance(username, six.string_types):
             username = username.username
         for thread in sorted(set(self.inbox + self.outbox),
                              key=lambda t: t.datetime, reverse=True):
@@ -148,5 +151,15 @@ class User(object):
         response = self._session.okc_get('quickmatch', params={'okc_api': 1})
         return Profile(self._session, response.json()['sn'])
 
+    def copy(self, profile_or_user):
+        """Create a :class:`~okcupyd.profile_copy.Copy` instance with the
+        provided object as the source and this :class:`~okcupyd.user.User`
+        as the destination.
+
+        :param profile_or_user: A :class:`~okcupyd.user.User` or
+                                :class:`~okcupyd.profile.Profile` object.
+        """
+        return Copy(profile_or_user, self)
+
     def __repr__(self):
         return 'User("{0}")'.format(self.profile.username)
